@@ -50,8 +50,8 @@ server_new_client(int fd, gss_cred_id_t creds)
     OM_uint32 minor = 0;
     OM_uint32 acc_minor, time_rec;
     int flags, status;
-    static const OM_uint32 req_gss_flags
-        = (GSS_C_MUTUAL_FLAG | GSS_C_CONF_FLAG | GSS_C_INTEG_FLAG);
+    static const OM_uint32 req_gss_flags =
+        (GSS_C_MUTUAL_FLAG | GSS_C_CONF_FLAG | GSS_C_INTEG_FLAG);
 
     /* Create and initialize a new client struct. */
     client = xcalloc(1, sizeof(struct client));
@@ -84,8 +84,8 @@ server_new_client(int fd, gss_cred_id_t creds)
         free(buffer);
 
     /* Accept the initial (worthless) token. */
-    status = token_recv(client->fd, &flags, &recv_tok, TOKEN_MAX_LENGTH,
-                        TIMEOUT);
+    status =
+        token_recv(client->fd, &flags, &recv_tok, TOKEN_MAX_LENGTH, TIMEOUT);
     if (status != TOKEN_OK) {
         warn_token("receiving initial token", status, major, minor);
         goto fail;
@@ -118,8 +118,9 @@ server_new_client(int fd, gss_cred_id_t creds)
         debug("received context token (size=%lu)",
               (unsigned long) recv_tok.length);
         major = gss_accept_sec_context(&acc_minor, &client->context, creds,
-                    &recv_tok, GSS_C_NO_CHANNEL_BINDINGS, &name, &doid,
-                    &send_tok, &client->flags, &time_rec, NULL);
+                                       &recv_tok, GSS_C_NO_CHANNEL_BINDINGS,
+                                       &name, &doid, &send_tok, &client->flags,
+                                       &time_rec, NULL);
         free(recv_tok.value);
 
         /* Send back a token if we need to. */
