@@ -44,7 +44,11 @@ server_ssh_parse_command(const char *command)
     const char *p;
     size_t i, length;
     char quote = '\0';
-    enum state { SEPARATOR, ARG, QUOTE } state;
+    enum state {
+        SEPARATOR,
+        ARG,
+        QUOTE
+    } state;
 
     /*
      * Parse the string using a state engine.  We can be in one of three
