@@ -2,6 +2,7 @@
  * Testing interface to the fake getpwnam replacement.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
+ * Copyright 2022 Russ Allbery <eagle@eyrie.org>
  * Copyright 2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
@@ -23,7 +24,7 @@ BEGIN_DECLS
  * Sets the struct passwd returned by getpwnam calls.  The last struct passed
  * to this function will be returned provided the pw_name matches.
  */
-void fake_set_passwd(struct passwd *pwd);
+void fake_set_passwd(const struct passwd *pwd);
 
 /* Frees the memory allocated by fake_set_passwd. */
 void fake_free_passwd(void);
