@@ -15,7 +15,7 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2017 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2017, 2022 Russ Allbery <eagle@eyrie.org>
  * Copyright 2006-2007, 2009-2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
@@ -42,7 +42,7 @@
 
 #include <config.h>
 #ifdef HAVE_KRB5
-# include <portable/krb5.h>
+#    include <portable/krb5.h>
 #endif
 #include <portable/system.h>
 
@@ -59,7 +59,7 @@
  * to handle the possible patterns for kinit commands as an array.
  */
 #if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 2) || defined(__clang__)
-# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#    pragma GCC diagnostic ignored "-Wformat-nonliteral"
 #endif
 
 
@@ -158,12 +158,11 @@ kerberos_kinit(void)
 static void
 kerberos_kinit(void)
 {
-    static const char * const format[] = {
+    static const char *const format[] = {
         "kinit --no-afslog -k -t %s %s >/dev/null 2>&1 </dev/null",
         "kinit -k -t %s %s >/dev/null 2>&1 </dev/null",
         "kinit -t %s %s >/dev/null 2>&1 </dev/null",
-        "kinit -k -K %s %s >/dev/null 2>&1 </dev/null"
-    };
+        "kinit -k -K %s %s >/dev/null 2>&1 </dev/null"};
     FILE *file;
     char *path;
     char principal[BUFSIZ], *command;
@@ -212,9 +211,11 @@ kerberos_kinit(void)
  * process so that test programs that fork don't remove the ticket cache still
  * used by the main program.
  */
-static void
-kerberos_free(void)
+void
+kerberos_free(struct kerberos_config *config_arg)
 {
+    if (config_arg != config)
+        bail("invalid argument to kerberos_free");
     test_tmpdir_free(tmpdir_ticket);
     tmpdir_ticket = NULL;
     if (config != NULL) {
@@ -226,7 +227,14 @@ kerberos_free(void)
         free(config->password);
         free(config->pkinit_principal);
         free(config->pkinit_cert);
-        free(config);
+
+        /*
+         * Free config_arg rather than config, since otherwise cppcheck thinks
+         * that config_arg could be const, which while technically true would
+         * look very weird since config_arg is invalidated by calling this
+         * function.
+         */
+        free(config_arg);
         config = NULL;
     }
     if (krb5ccname != NULL) {
@@ -258,7 +266,7 @@ kerberos_cleanup(void)
         unlink(path);
         free(path);
     }
-    kerberos_free();
+    kerberos_free(config);
 }
 
 
@@ -274,7 +282,7 @@ kerberos_cleanup_handler(int success UNUSED, int primary)
     if (primary)
         kerberos_cleanup();
     else
-        kerberos_free();
+        kerberos_free(config);
 }
 
 
